![GitHub top language](https://img.shields.io/github/languages/top/thiliapr/python3-tprtools)
![GitHub License](https://img.shields.io/badge/license-GPL--3.0--or--later-blue)
![GitHub repo size](https://img.shields.io/github/repo-size/thiliapr/python3-tprtools)
![GitHub forks](https://img.shields.io/github/forks/thiliapr/python3-tprtools)
![GitHub Repo stars](https://img.shields.io/github/stars/thiliapr/python3-tprtools)

# Thiliapr Tools
A Python3 library written by thiliapr containing various tools.
- Version: 1.0.0
- License: Distributed under GPL-3.0 or later.

## Languages
- [简体中文](README.zh-CN.md)
- [English](README.md)

## Tools
### JSONPath
This is a simple JSONPath parser.
See [JSONPath Documentation](docs/jsonpath.md).
